WowFile
=======

A library to manipulate SparkMaker WOW files

WowViewer
=========

A graphical tool using WowFile to display and change parameter in SparkMaker WOW Files


Install
-------

If you are under windows and just want use the GUI tool, get it from one of the build [releases](/releases)

Else you can use pip to install the library and viewer:

```
sudo pip install WowFile
```

This will add "wowviewer" in your path, and you can access the `WowFile` class from python.
